@@ -138,7 +138,7 @@ The line search implementation from:
     Line search algorithms with guaranteed sufficient decrease.
     ACM Transactions on Mathematical Software (TOMS) 20.3 (1994): 286-307.
 """
-@with_kw struct MoreThuente{T} <: AbstractLineSearch
+@kwdef struct MoreThuente{T} <: AbstractLineSearch
     f_tol::T = 1e-4 # c_1 Wolfe sufficient decrease condition
     gtol::T = 0.9   # c_2 Wolfe curvature condition (Recommend 0.1 for GradientDescent)
     x_tol::T = 1e-8
@@ -162,7 +162,7 @@ function (ls::MoreThuente)(ϕdϕ,
                            alpha::T,
                            ϕ_0,
                            dϕ_0) where T
-    @unpack f_tol, gtol, x_tol, alphamin, alphamax, maxfev, cache = ls
+    (; f_tol, gtol, x_tol, alphamin, alphamax, maxfev, cache) = ls
     emptycache!(cache)
 
     iterfinitemax = -log2(eps(T))
